@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_vtenant.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -52,6 +52,9 @@ from trackme_libs_schema import trackme_schema_format_version
 # import trackme decision maker
 from trackme_libs_decisionmaker import convert_epoch_to_datetime
 
+# import the collections dict
+from collections_data import vtenant_account_default
+
 # import Splunk SDK client
 import splunklib.client as client
 import splunklib.results as results
@@ -1049,3 +1052,116 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
 
         else:
             return {"payload": trackme_vtenant_conf, "status": 200}
+
+    #
+    # Get tenant score configuration
+    #
+
+    def get_tenant_score_config(self, request_info, **kwargs):
+        """
+        | trackme url=/services/trackme/v2/vtenants/tenant_score_config mode=get params="{'tenant_id': 'mytenant'}"
+        """
+
+        # Declare main variables
+        tenant_id = None
+        describe = False
+
+        # Retrieve from query parameters
+        try:
+            params_dict = request_info.raw_args["query_parameters"]
+        except Exception as e:
+            params_dict = None
+
+        if params_dict is not None:
+            try:
+                tenant_id = params_dict.get("tenant_id")
+            except Exception as e:
+                tenant_id = None
+
+            # Check if describe is requested
+            try:
+                describe_param = params_dict.get("describe")
+                if describe_param in ("true", "True"):
+                    describe = True
+            except Exception as e:
+                describe = False
+        else:
+            describe = True
+
+        if describe or tenant_id is None:
+            response = {
+                "describe": "This endpoint retrieves the impact score configuration for a virtual tenant, it requires a GET call with the following query parameters:",
+                "resource_desc": "Get virtual tenant impact score configuration",
+                "resource_spl_example": "| trackme url=/services/trackme/v2/vtenants/tenant_score_config mode=get params=\"{'tenant_id': 'mytenant'}\"",
+                "options": [
+                    {
+                        "tenant_id": "The tenant identifier",
+                        "describe": "OPTIONAL: set to true to get endpoint description",
+                    }
+                ],
+            }
+
+            return {"payload": response, "status": 200}
+
+        # Get splunkd port
+        splunkd_port = request_info.server_rest_port
+
+        # set loglevel
+        loglevel = trackme_getloglevel(
+            request_info.system_authtoken, request_info.server_rest_port
+        )
+        logger.setLevel(loglevel)
+
+        # Get vtenant account configuration via REST call
+        url = f"{request_info.server_rest_uri}/servicesNS/nobody/trackme/trackme_vtenants/{tenant_id}"
+        vtenant_data = {}
+        vtenant_account_found = False
+
+        try:
+            # Get current vtenant account configuration
+            response = requests.get(
+                url,
+                headers={"Authorization": f"Splunk {request_info.system_authtoken}"},
+                verify=False,
+                params={"output_mode": "json"},
+                timeout=600,
+            )
+            if response.status_code in (200, 201, 204):
+                logger.info(f"successfully retrieved vtenant configuration")
+                vtenant_data_json = response.json()
+                vtenant_data_current = vtenant_data_json["entry"][0]["content"]
+                vtenant_account_found = True
+                vtenant_data = dict(vtenant_data_current)
+            else:
+                error_msg = f"failed to retrieve vtenant configuration, status_code={response.status_code}"
+                logger.error(error_msg)
+
+        except Exception as e:
+            error_msg = f"failed to retrieve vtenant configuration, exception={str(e)}"
+            logger.error(error_msg)
+
+        if not vtenant_account_found:
+            error_msg = f'tenant_id="{tenant_id}" cannot be found'
+            logger.error(error_msg)
+            return {
+                "payload": {
+                    "response": error_msg,
+                },
+                "status": 404,
+            }
+
+        # Extract all impact_score_* fields from the tenant account configuration
+        # If a field is not present, use the default from vtenant_account_default
+        score_config = {}
+        for field_name in vtenant_account_default.keys():
+            if field_name.startswith("impact_score_"):
+                score_config[field_name] = vtenant_data.get(
+                    field_name, vtenant_account_default[field_name]
+                )
+
+        response = {
+            "tenant_id": tenant_id,
+            "score_config": score_config,
+        }
+
+        return {"payload": response, "status": 200}
